@@ -11,8 +11,8 @@ function(formula, data, subset, na.action=na.rpart, ...)
     cl <- match.call()
     if(missing(formula)
        || (length(formula) != 3)
-       || (length(attr(terms(formula[-2]), "term.labels")) < 1)
-       || (length(attr(terms(formula[-3]), "term.labels")) != 1))
+       || (length(attr(terms(formula[-2], data = data), "term.labels")) < 1)
+       || (length(attr(terms(formula[-3], data = data), "term.labels")) != 1))
         stop("formula missing or incorrect")
     m <- match.call(expand.dots = FALSE)
     if(is.matrix(eval(m$data, parent.frame())))
